==> haskell-neat-interpolation-0.3.2.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.4
id: neat-interpolation-0.3.2.4-4GWgvB1KZqa5ptZ3OwCaqO
key: neat-interpolation-0.3.2.4-4GWgvB1KZqa5ptZ3OwCaqO
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: d6740984c96f2cc07138e9c7c5afef59
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/neat-interpolation-0.3.2.4
hs-libraries: HSneat-interpolation-0.3.2.4-4GWgvB1KZqa5ptZ3OwCaqO
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-7.0.4-1CpsR9z4yywE3fIGM7EYlI template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-neat-interpolation-0.3.2.4-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-neat-interpolation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: neat-interpolation
version: 0.3.2.4
id: neat-interpolation-0.3.2.4-6by3alsEZ51D6Tx0fCfE1Q
key: neat-interpolation-0.3.2.4-6by3alsEZ51D6Tx0fCfE1Q
license: MIT
copyright: (c) 2013, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/neat-interpolation
synopsis: A quasiquoter for neat and simple multiline text interpolation
description:
    A quasiquoter for producing Text values with support for
    a simple interpolation of input values.
    It removes the excessive indentation from the input and
    accurately manages the indentation of all lines of the interpolated variables.
category: String, QuasiQuotes
abi: 62987bbbf92e763e742fae986db5edd5
exposed: True
exposed-modules:
    NeatInterpolation
hidden-modules: NeatInterpolation.Parsing NeatInterpolation.String
import-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
library-dirs: /usr/lib/ghc-8.6.4/site-local/neat-interpolation-0.3.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/neat-interpolation-0.3.2.4
hs-libraries: HSneat-interpolation-0.3.2.4-6by3alsEZ51D6Tx0fCfE1Q
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    megaparsec-7.0.4-LtBOPHXtadb29GI7W5CNMI template-haskell-2.14.0.0
    text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-neat-interpolation/html/neat-interpolation.haddock
haddock-html: /usr/share/doc/haskell-neat-interpolation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
